@@ -2,8 +2,8 @@ import re
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
 
 class CatLegend(BasicComicModule):
-    latestUrl = 'http://catlegend.rampagesession.com/'
-    imageUrl = 'http://catlegend.rampagesession.com/index.php?strip_id=%s'
+    latestUrl = 'http://catlegends.com/'
+    imageUrl = 'http://catlegends.com/index.php?strip_id=%s'
     imageSearch = re.compile(r'<img.+?src="(istrip_files/strips/[^"]+)"', re.IGNORECASE)
     prevSearch = re.compile(r'<a[^>]+href="(/index.php\?strip_id=\d+?)"><img[^>]+alt="Previous comic"', re.IGNORECASE)
     help = 'Index format: n (unpadded)'
