@@ -4,6 +4,6 @@ from dosage.modules.helpers.BasicComicModule import BasicComicModule
 class NewWorld(BasicComicModule):
     latestUrl = 'http://www.tfsnewworld.com/'
     imageUrl = 'http://www.tfsnewworld.com/?date=%s'
-    imageSearch = re.compile(r'<img.+?src="(strips/.+?)"', re.IGNORECASE)
-    prevSearch = re.compile(r'<a href="(\?date=\d+?)"><img src="previous\.gif"', re.IGNORECASE)
+    imageSearch = re.compile(r'<img.+?src="(comics/.+?)"', re.IGNORECASE)
+    prevSearch = re.compile(r'</td>[^>].+?"(\?date.*?)" .*?previous.png', re.IGNORECASE)
     help = 'Index format: yyyymmdd'
