@@ -17,7 +17,6 @@ class UComics(BasicComicModule):
         'agnes',
         'andycapp',
         'animalcrackers',
-        'animatedoliphant',
         'annie',
         'anntelnaes',
         'askshagg',
@@ -38,7 +37,6 @@ class UComics(BasicComicModule):
         'brendastarr',
         'brewsterrockit',
         'broomhilda',
-        'brucehammond',
         'calvinandhobbes',
         'cathy',
         'ceodad',
@@ -84,7 +82,6 @@ class UComics(BasicComicModule):
         'herbandjamaal',
         'housebroken',
         'hubertandabby',
-        'idiotbox',
         'inkpen',
         'inthebleachers',
         'jackhiggins',
